@@ -1,9 +1,13 @@
+import logging
+
 from django.apps import AppConfig
 
+logger = logging.getLogger(__name__)
+
 
 class VerifyEmailConfig(AppConfig):
     name = 'verify_email'
 
     def ready(self):
-        print('[Email Verification] : importing signals    - OK.')
+        logger.info('[Email Verification] : importing signals    - OK.')
         import verify_email.signals
