@@ -1,7 +1,12 @@
+import logging
+
 from django.db.models.signals import post_save
 from django.dispatch import receiver
+
 from .models import LinkCounter, USER
 
+logger = logging.getLogger(__name__)
+
 
 @receiver(post_save, sender=USER)
 def increase_count(sender, instance, created, **kwargs):
@@ -14,4 +19,4 @@ def save_count(sender, instance, **kwargs):
     try:
         instance.linkcounter.save()
     except Exception as err:
-        print(err)
+        logger.error(err)
