@@ -1,7 +1,9 @@
+import logging
 from datetime import timedelta
-from django.core import signing
 from binascii import Error as BASE64ERROR
 from base64 import urlsafe_b64encode, urlsafe_b64decode
+
+from django.core import signing
 from django.contrib.auth import get_user_model
 from django.contrib.auth.tokens import default_token_generator
 
@@ -12,6 +14,8 @@ __all__ = [
     "TokenManager"
 ]
 
+logger = logging.getLogger(__name__)
+
 
 class TokenManager(signing.TimestampSigner):
     """
@@ -98,7 +102,7 @@ class TokenManager(signing.TimestampSigner):
         try:
             return int(user.linkcounter.sent_count)
         except Exception as e:
-            print(e)
+            logger.error(e)
             return False
 
     @staticmethod
@@ -217,18 +221,20 @@ class TokenManager(signing.TimestampSigner):
                     return False
 
                 except signing.SignatureExpired:
-                    print(f'\n{"~" * 40}\n[ERROR] : The link is Expired!\n{"~" * 40}\n')
+                    logger.warning(f'\n{"~" * 40}\n[WARNING] : The link is Expired!\n{"~" * 40}\n')
                     user = self.get_user_by_token(decoded_email, self.__decrypt_expired_user(decoded_token))
                     if not self.__verify_attempts(user):
                         raise MaxRetriesExceeded()
                     raise
 
                 except signing.BadSignature:
-                    print(f'\n{"~" * 40}\n[CRITICAL] : X_x --> CAUTION : LINK SIGNATURE ALTERED! <-- x_X\n{"~" * 40}\n')
+                    logger.critical(
+                        f'\n{"~" * 40}\n[CRITICAL] : X_x --> CAUTION : LINK SIGNATURE ALTERED! <-- x_X\n{"~" * 40}\n'
+                    )
                     raise
             else:
                 user = self.get_user_by_token(decoded_email, decoded_token)
                 return user if user else False
         else:
-            print(f'\n{"~" * 40}\n[ERROR] : Error occurred in decoding the link!\n{"~" * 40}\n')
+            logger.error(f'\n{"~" * 40}\nError occurred in decoding the link!\n{"~" * 40}\n')
             return False
